Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(88)

Unified Diff: media/audio/android/opensles_output.h

Issue 2917203002: Add MuteableAudioOutputStream interface to export SetMute(). (Closed)
Patch Set: Bug fixed Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « media/audio/android/muteable_audio_output_stream.h ('k') | media/audio/audio_manager_base.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/audio/android/opensles_output.h
diff --git a/media/audio/android/opensles_output.h b/media/audio/android/opensles_output.h
index 80d8929769a68f7cd46ed1afeef117ff5838346d..17a91aaa52437589dbb58c078ef848c57acf70ab 100644
--- a/media/audio/android/opensles_output.h
+++ b/media/audio/android/opensles_output.h
@@ -16,8 +16,8 @@
#include "base/macros.h"
#include "base/synchronization/lock.h"
#include "base/threading/thread_checker.h"
+#include "media/audio/android/muteable_audio_output_stream.h"
#include "media/audio/android/opensles_util.h"
-#include "media/audio/audio_io.h"
#include "media/base/audio_parameters.h"
#include "media/base/audio_timestamp_helper.h"
@@ -48,7 +48,7 @@ class AudioManagerAndroid;
// This class is created and lives on the Audio Manager thread but recorded
// audio buffers are given to us from an internal OpenSLES audio thread.
// All public methods should be called on the Audio Manager thread.
-class OpenSLESOutputStream : public AudioOutputStream {
+class OpenSLESOutputStream : public MuteableAudioOutputStream {
public:
static const int kMaxNumOfBuffersInQueue = 2;
@@ -58,7 +58,7 @@ class OpenSLESOutputStream : public AudioOutputStream {
~OpenSLESOutputStream() override;
// Implementation of AudioOutputStream.
bool Open() override;
void Close() override;
void Start(AudioSourceCallback* callback) override;
@@ -68,7 +68,7 @@ class OpenSLESOutputStream : public AudioOutputStream {
// Set the value of |muted_|. It does not affect |volume_| which can be
// got by calling GetVolume(). See comments for |muted_| below.
- void SetMute(bool muted);
+ void SetMute(bool muted) override;
private:
bool CreatePlayer();
« no previous file with comments | « media/audio/android/muteable_audio_output_stream.h ('k') | media/audio/audio_manager_base.h » ('j') | no next file with comments »
@@ -58,7 +58,7 @@ class OpenSLESOutputStream : public AudioOutputStream {
~OpenSLESOutputStream() override;
- // Implementation of AudioOutputStream.
+ // Implementation of MuteableAudioOutputStream.
bool Open() override;
void Close() override;

Powered by Google App Engine
This is Rietveld 408576698